commit 65235febf78eb11192ecf648e31223963cbd3b79
Author: Cliff Brake <cbrake@bec-systems.com>
Date:   Mon Feb 7 18:01:22 2011 -0500

    enable Micron 4-bit ECC engine

diff --git a/drivers/mtd/nand/nand_base.c b/drivers/mtd/nand/nand_base.c
index 1f75a1b..5f53b20 100644
--- a/drivers/mtd/nand/nand_base.c
+++ b/drivers/mtd/nand/nand_base.c
@@ -70,6 +70,7 @@ static struct nand_ecclayout nand_oob_16 = {
 		 . length = 8} }
 };
 
+#if 0
 static struct nand_ecclayout nand_oob_64 = {
 	.eccbytes = 24,
 	.eccpos = {
@@ -80,6 +81,24 @@ static struct nand_ecclayout nand_oob_64 = {
 		{.offset = 2,
 		 .length = 38} }
 };
+#endif
+
+/* MICRON: modified OOB Layout */
+static struct nand_ecclayout nand_oob_64 = {
+	.eccbytes = 32,
+	.eccpos = {
+		8, 9, 10, 11, 12, 13, 14, 15,
+		24, 25, 26, 27, 28, 29, 30, 31,
+		40, 41, 42, 43, 44, 45, 46, 47,
+		56, 57, 58, 59, 60, 61, 62, 63
+	},
+	.oobfree = {
+		{ .offset = 4, .length = 4 },
+		{ .offset = 20, .length = 4 },
+		{ .offset = 36, .length = 4 },
+		{ .offset = 52, .length = 4 },
+	},
+};
 
 static struct nand_ecclayout nand_oob_128 = {
 	.eccbytes = 48,
@@ -689,6 +708,7 @@ static void nand_command_lp(struct mtd_info *mtd, unsigned int command,
 	 * status, sequential in, and deplete1 need no delay
 	 */
 	switch (command) {
+	int status,cnt;
 
 	case NAND_CMD_CACHEDPROG:
 	case NAND_CMD_PAGEPROG:
@@ -737,6 +757,28 @@ static void nand_command_lp(struct mtd_info *mtd, unsigned int command,
 		chip->cmd_ctrl(mtd, NAND_CMD_NONE,
 			       NAND_NCE | NAND_CTRL_CHANGE);
 
+		/* MICRON: wait until part RDY; tR_ECC max */
+		for(cnt=0; cnt<70; cnt++) {
+			ndelay(1000); /* 1 usec delay */
+			chip->cmdfunc(mtd, NAND_CMD_STATUS, -1, -1);
+			status = chip->read_byte(mtd);
+			if( (status & NAND_STATUS_READY ) )
+				break;
+		}
+
+		/* MICRON: Look for STATUS bit ERR */
+		if( (status & NAND_STATUS_FAIL) ) {
+			printk(KERN_WARNING
+				"WARNING :: READ Operation ECC Error: 0x%02x delay %d usec\n",
+				status,cnt+1);
+			/* do something on fail */
+		}
+		/* MICRON: re-issue CMD0 after STATUS Check */
+		chip->cmd_ctrl(mtd, NAND_CMD_READ0,
+		NAND_NCE | NAND_CLE | NAND_CTRL_CHANGE);
+		chip->cmd_ctrl(mtd, NAND_CMD_NONE,
+		NAND_NCE | NAND_CTRL_CHANGE);
+
 		/* This applies to read commands */
 	default:
 		/*
diff --git a/drivers/mtd/nand/omap2.c b/drivers/mtd/nand/omap2.c
index 15682ec..28644ec 100644
--- a/drivers/mtd/nand/omap2.c
+++ b/drivers/mtd/nand/omap2.c
@@ -885,6 +885,7 @@ static int __devinit omap_nand_probe(struct platform_device *pdev)
 #else
 	info->nand.ecc.mode = NAND_ECC_SOFT;
 #endif
+	info->nand.ecc.mode = NAND_ECC_NONE;
 
 	/* DIP switches on some boards change between 8 and 16 bit
 	 * bus widths for flash.  Try the other width if the first try fails.
